==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/c6/c6dcb48f0fa879e1750289e4f45d21c8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png */
class __TwigTemplate_73130fc9f204752c3e93bd7a1fe065ea extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\0004\000\000\000%\000\000\000
\000\000MIDATxֿkqSBTO\"@VȒI`
EE%b~\"n:8A@ PAqqJ\$p(zO
+k}wᾹ\$SLdEQ\000YoA}\"UcA[*LԆ\"t1 !wAjL^3+':iP;GlLuD6^}ʠ,z&#1FȥzAoA&1F]/(C{)\$ARAއE!Fyف2h;O0@6i>*걠bA80Q&f?}ZX#M&kP;dc\"#Qނz&#xʠ71B\",xgAYcfyZW5A#Q{v{]lCg[=wUXr86nZW1PmOAo<jV4i=ס^q>-7A,71Uz~S.a Ɩ ]^7?w3-4Ч&%\\i#~APvQ5(L?\\zO\\\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/c6/c6dcb48f0fa879e1750289e4f45d21c8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png */
class __TwigTemplate_73130fc9f204752c3e93bd7a1fe065ea extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\0004\000\000\000%\000\000\000
\000\000MIDATxֿkqSBTO\"@VȒI`
EE%b~\"n:8A@ PAqqJ\$p(zO
+k}wᾹ\$SLdEQ\000YoA}\"UcA[*LԆ\"t1 !wAjL^3+':iP;GlLuD6^}ʠ,z&#1FȥzAoA&1F]/(C{)\$ARAއE!Fyف2h;O0@6i>*걠bA80Q&f?}ZX#M&kP;dc\"#Qނz&#xʠ71B\",xgAYcfyZW5A#Q{v{]lCg[=wUXr86nZW1PmOAo<jV4i=ס^q>-7A,71Uz~S.a Ɩ ]^7?w3-4Ч&%\\i#~APvQ5(L?\\zO\\\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/css/libraries/chosen/chosen-sprite.png");
    }
}
